@@ -11,6 +11,10 @@ pub struct CrateContext {
 }
 
 impl CrateContext {
+    pub fn consts(&self) -> impl Iterator<Item = &syn::ItemConst> {
+        self.modules.iter().flat_map(|(_, ctx)| ctx.consts())
+    }
+
     pub fn structs(&self) -> impl Iterator<Item = &syn::ItemStruct> {
         self.modules.iter().flat_map(|(_, ctx)| ctx.structs())
     }
@@ -183,4 +187,11 @@ impl ParsedModule {
             _ => None,
         })
     }
+
+    fn consts(&self) -> impl Iterator<Item = &syn::ItemConst> {
+        self.items.iter().filter_map(|i| match i {
+            syn::Item::Const(item) => Some(item),
+            _ => None,
+        })
+    }
 }
